The hardware and bandwidth for this mirror is donated by dogado GmbH, the Webhosting and Full Service-Cloud Provider. Check out our Wordpress Tutorial.
If you wish to report a bug, or if you are interested in having us mirror your free-software or open-source project, please feel free to contact us at mirror[@]dogado.de.

Package {RSSRMR}


Type: Package
Title: Robust Self-Representation Sparse Reconstruction and Manifold Regularization
Version: 0.1.0
Description: Feature selection and clustering classification under the presence of multivariate outliers in high-dimensional unlabeled data.
License: GPL-3
Encoding: UTF-8
RoxygenNote: 8.0.0
Imports: robustbase, stats
Suggests: knitr, rmarkdown, testthat (≥ 3.0.0)
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-05-23 07:09:27 UTC; cvalley
Author: Abdul Wahid [aut, cre]
Maintainer: Abdul Wahid <ab_wahid1996@yahoo.com>
Repository: CRAN
Date/Publication: 2026-05-29 09:50:07 UTC

Robust Self-Representation Sparse Reconstruction and Manifold Regularization

Description

Performs robust sparse self-representation with manifold regularization.

Usage

RSSRMR(x, Wt, L, alpha = 1, beta = 1, epsilon = 0.001, maxites = 50)

Arguments

x

Numeric data matrix.

Wt

Weight matrix.

L

Laplacian matrix.

alpha

Regularization parameter.

beta

Graph regularization parameter.

epsilon

Convergence threshold.

maxites

Maximum number of iterations.

Value

A list containing:

Optimum.A

Coefficient matrix

Optimum.G

Diagonal weight matrix

Examples

set.seed(6542)

cluster1 <- matrix(
  rnorm(12 * 5, mean = 2, sd = 0.5),
  nrow = 12
)

cluster2 <- matrix(
  rnorm(13 * 5, mean = 7, sd = 0.5),
  nrow = 13
)

X <- rbind(cluster1, cluster2)

wd <- diag(runif(25))
lp <- diag(runif(25))

fit <- RSSRMR(
  x = X,
  Wt = wd,
  L = lp
)

fit$Optimum.G


Robust Distance Weights

Description

Computes robust observation weights.

Usage

dweight(x, q = 0.9)

Arguments

x

Numeric data matrix.

q

Quantile threshold.

Value

Numeric vector of weights.

Examples

set.seed(123)

x <- matrix(rnorm(50), nrow = 10)

dweight(x)

These binaries (installable software) and packages are in development.
They may not be fully stable and should be used with caution. We make no claims about them.
Health stats visible at Monitor.